/* Copyright (c) 2001 Matej Pfajfar.
 * Copyright (c) 2001-2004, Roger Dingledine.
 * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson.
 * Copyright (c) 2007-2019, The Tor Project, Inc. */
/* See LICENSE for licensing information */

#ifndef DIRAUTH_SYS_H
#define DIRAUTH_SYS_H

extern const struct subsys_fns_t sys_dirauth;

#endif /* !defined(DIRAUTH_SYS_H) */
